AdyenClient.BalancePlatform.WebhookSettings (AdyenClient v1.0.0)

Copy Markdown View Source

Balance Platform — Balance Webhook Settings.

Configure per-balance-account webhook URLs to receive balancePlatform.balanceAccount.balance.updated and related balance events.

Summary

Functions

Create a balance webhook setting for a balance account.

Delete a balance webhook setting.

Get a specific balance webhook setting.

Get all balance webhook settings for a balance account.

Update a balance webhook setting.

Functions

create(account_id, params, opts \\ [])

@spec create(String.t(), map(), keyword()) :: AdyenClient.Client.response()

Create a balance webhook setting for a balance account.

delete(account_id, webhook_id, opts \\ [])

Delete a balance webhook setting.

get(account_id, webhook_id, opts \\ [])

Get a specific balance webhook setting.

list(account_id, opts \\ [])

@spec list(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get all balance webhook settings for a balance account.

update(account_id, webhook_id, params, opts \\ [])

@spec update(String.t(), String.t(), map(), keyword()) ::
  AdyenClient.Client.response()

Update a balance webhook setting.