AdyenClient.Capital (AdyenClient v1.0.0)

Copy Markdown View Source

Adyen Capital API (v1) — embedded financing / business cash advances.

Summary

Functions

Calculate a preliminary offer for a financing amount.

Convert a dynamic offer to a static grant offer.

Get details of a specific grant.

Get grant account information.

Get a static grant offer.

List all disbursements for a grant.

Get all available dynamic offers.

List all available static grant offers.

Get all grants for an account holder.

Request a capital grant.

Update repayment configuration for a disbursement.

Functions

calculate_dynamic_offer(offer_id, params, opts \\ [])

@spec calculate_dynamic_offer(String.t(), map(), keyword()) ::
  AdyenClient.Client.response()

Calculate a preliminary offer for a financing amount.

create_grant_offer(offer_id, params, opts \\ [])

@spec create_grant_offer(String.t(), map(), keyword()) ::
  AdyenClient.Client.response()

Convert a dynamic offer to a static grant offer.

get_disbursement(grant_id, disbursement_id, opts \\ [])

@spec get_disbursement(String.t(), String.t(), keyword()) ::
  AdyenClient.Client.response()

Get a specific disbursement.

get_grant(grant_id, opts \\ [])

@spec get_grant(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get details of a specific grant.

get_grant_account(id, opts \\ [])

@spec get_grant_account(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get grant account information.

get_grant_offer(id, opts \\ [])

@spec get_grant_offer(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get a static grant offer.

list_disbursements(grant_id, opts \\ [])

@spec list_disbursements(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

List all disbursements for a grant.

list_dynamic_offers(opts \\ [])

@spec list_dynamic_offers(keyword()) :: AdyenClient.Client.response()

Get all available dynamic offers.

list_grant_offers(opts \\ [])

@spec list_grant_offers(keyword()) :: AdyenClient.Client.response()

List all available static grant offers.

list_grants(opts \\ [])

@spec list_grants(keyword()) :: AdyenClient.Client.response()

Get all grants for an account holder.

request_grant(params, opts \\ [])

@spec request_grant(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Request a capital grant.

update_disbursement(grant_id, disbursement_id, params, opts \\ [])

@spec update_disbursement(String.t(), String.t(), map(), keyword()) ::
  AdyenClient.Client.response()

Update repayment configuration for a disbursement.