AdyenClient.ClassicPlatforms.Fund (AdyenClient v1.0.0)

Copy Markdown View Source

Adyen Classic Platforms Fund API (v6).

Summary

Functions

Get the balances of an account holder.

Send a direct debit request.

Pay out funds from an account to the account holder.

Refund all unpaid-out transactions since the most recent payout.

Set up a beneficiary relationship.

Get a list of transactions for an account holder.

Transfer funds between platform accounts.

Functions

account_holder_balance(params, opts \\ [])

@spec account_holder_balance(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get the balances of an account holder.

debit_account_holder(params, opts \\ [])

@spec debit_account_holder(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Send a direct debit request.

payout_account_holder(params, opts \\ [])

@spec payout_account_holder(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Pay out funds from an account to the account holder.

refund_funds_transfer(params, opts \\ [])

@spec refund_funds_transfer(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Refund a funds transfer.

refund_not_paid_out_transfers(params, opts \\ [])

@spec refund_not_paid_out_transfers(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Refund all unpaid-out transactions since the most recent payout.

setup_beneficiary(params, opts \\ [])

@spec setup_beneficiary(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Set up a beneficiary relationship.

transaction_list(params, opts \\ [])

@spec transaction_list(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get a list of transactions for an account holder.

transfer_funds(params, opts \\ [])

@spec transfer_funds(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Transfer funds between platform accounts.