AdyenClient.CloudDevice (AdyenClient v1.0.0)

Copy Markdown View Source

Adyen Cloud Device API (v1).

REST wrapper to send Terminal API messages to cloud-connected terminals without needing direct network access to the terminal.

Summary

Functions

Send a Terminal API request and receive an asynchronous response.

Get the connection status of a device.

Get a list of connected devices for a merchant account.

Send a Terminal API request and receive a synchronous response.

Functions

async(merchant_account, device_id, params, opts \\ [])

Send a Terminal API request and receive an asynchronous response.

get_status(merchant_account, device_id, opts \\ [])

@spec get_status(String.t(), String.t(), keyword()) :: AdyenClient.Client.response()

Get the connection status of a device.

list_connected(merchant_account, opts \\ [])

@spec list_connected(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get a list of connected devices for a merchant account.

sync(merchant_account, device_id, params, opts \\ [])

Send a Terminal API request and receive a synchronous response.