Management API — Payment method settings.
Summary
Functions
Add an Apple Pay domain to a payment method.
Get details of a specific payment method.
Get Apple Pay domains for a payment method.
Get all payment methods configured for a merchant.
Request a new payment method for a merchant.
Update a payment method configuration.
Functions
@spec add_apple_pay_domain(String.t(), String.t(), map(), keyword()) :: AdyenClient.Client.response()
Add an Apple Pay domain to a payment method.
@spec get(String.t(), String.t(), keyword()) :: AdyenClient.Client.response()
Get details of a specific payment method.
@spec get_apple_pay_domains(String.t(), String.t(), keyword()) :: AdyenClient.Client.response()
Get Apple Pay domains for a payment method.
@spec list( String.t(), keyword() ) :: AdyenClient.Client.response()
Get all payment methods configured for a merchant.
@spec request(String.t(), map(), keyword()) :: AdyenClient.Client.response()
Request a new payment method for a merchant.
@spec update(String.t(), String.t(), map(), keyword()) :: AdyenClient.Client.response()
Update a payment method configuration.