AdyenClient.Management.PayoutSettings (AdyenClient v1.0.0)

Copy Markdown View Source

Management API — Payout Settings at merchant level.

Manage payout destinations (bank accounts, e-wallets) for a merchant account.

Summary

Functions

Add a payout setting to a merchant account.

Get a specific payout setting.

Get a list of payout settings for a merchant account.

Functions

add(merchant_id, params, opts \\ [])

Add a payout setting to a merchant account.

delete(merchant_id, payout_settings_id, opts \\ [])

Delete a payout setting.

get(merchant_id, payout_settings_id, opts \\ [])

Get a specific payout setting.

list(merchant_id, opts \\ [])

@spec list(
  String.t(),
  keyword()
) :: AdyenClient.Client.response()

Get a list of payout settings for a merchant account.

update(merchant_id, payout_settings_id, params, opts \\ [])

@spec update(String.t(), String.t(), map(), keyword()) ::
  AdyenClient.Client.response()

Update a payout setting.