AdyenClient.Management.TerminalManagement (AdyenClient v1.0.0)

Copy Markdown View Source

Terminal Management / postfmapi (v1) — deprecated.

Assign terminals and look up terminal/store/account associations. For new integrations use AdyenClient.Management.Terminals.

Summary

Functions

Assign terminals to a merchant account or store.

Get the stores of a merchant account.

Get details of a terminal.

Get the merchant account or store a terminal is assigned to.

Get the list of terminals under a merchant account or store.

Functions

assign(params, opts \\ [])

@spec assign(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Assign terminals to a merchant account or store.

get_stores(params, opts \\ [])

@spec get_stores(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get the stores of a merchant account.

get_terminal(params, opts \\ [])

@spec get_terminal(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get details of a terminal.

get_terminal_under(params, opts \\ [])

@spec get_terminal_under(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get the merchant account or store a terminal is assigned to.

list_terminals(params, opts \\ [])

@spec list_terminals(
  map(),
  keyword()
) :: AdyenClient.Client.response()

Get the list of terminals under a merchant account or store.