Balance Platform — Additional Account Holder endpoints.
Supplements AdyenClient.BalancePlatform with tax form summary and
transaction rule listing for account holders.
Summary
Functions
Get a summary of tax forms for an account holder.
Functions
@spec get_tax_form_summary(String.t(), map(), keyword()) :: AdyenClient.Client.response()
Get a summary of tax forms for an account holder.