Adyen Capital API (v1) — embedded financing / business cash advances.
Summary
Functions
Calculate a preliminary offer for a financing amount.
Convert a dynamic offer to a static grant offer.
Get a specific disbursement.
Get details of a specific grant.
Get grant account information.
Get a static grant offer.
List all disbursements for a grant.
Get all available dynamic offers.
List all available static grant offers.
Get all grants for an account holder.
Request a capital grant.
Update repayment configuration for a disbursement.
Functions
@spec calculate_dynamic_offer(String.t(), map(), keyword()) :: AdyenClient.Client.response()
Calculate a preliminary offer for a financing amount.
@spec create_grant_offer(String.t(), map(), keyword()) :: AdyenClient.Client.response()
Convert a dynamic offer to a static grant offer.
@spec get_disbursement(String.t(), String.t(), keyword()) :: AdyenClient.Client.response()
Get a specific disbursement.
@spec get_grant( String.t(), keyword() ) :: AdyenClient.Client.response()
Get details of a specific grant.
@spec get_grant_account( String.t(), keyword() ) :: AdyenClient.Client.response()
Get grant account information.
@spec get_grant_offer( String.t(), keyword() ) :: AdyenClient.Client.response()
Get a static grant offer.
@spec list_disbursements( String.t(), keyword() ) :: AdyenClient.Client.response()
List all disbursements for a grant.
@spec list_dynamic_offers(keyword()) :: AdyenClient.Client.response()
Get all available dynamic offers.
@spec list_grant_offers(keyword()) :: AdyenClient.Client.response()
List all available static grant offers.
@spec list_grants(keyword()) :: AdyenClient.Client.response()
Get all grants for an account holder.
@spec request_grant( map(), keyword() ) :: AdyenClient.Client.response()
Request a capital grant.
@spec update_disbursement(String.t(), String.t(), map(), keyword()) :: AdyenClient.Client.response()
Update repayment configuration for a disbursement.