Adyen Classic Platforms Fund API (v6).
Summary
Functions
Get the balances of an account holder.
Send a direct debit request.
Pay out funds from an account to the account holder.
Refund a funds transfer.
Refund all unpaid-out transactions since the most recent payout.
Set up a beneficiary relationship.
Get a list of transactions for an account holder.
Transfer funds between platform accounts.
Functions
@spec account_holder_balance( map(), keyword() ) :: AdyenClient.Client.response()
Get the balances of an account holder.
@spec debit_account_holder( map(), keyword() ) :: AdyenClient.Client.response()
Send a direct debit request.
@spec payout_account_holder( map(), keyword() ) :: AdyenClient.Client.response()
Pay out funds from an account to the account holder.
@spec refund_funds_transfer( map(), keyword() ) :: AdyenClient.Client.response()
Refund a funds transfer.
@spec refund_not_paid_out_transfers( map(), keyword() ) :: AdyenClient.Client.response()
Refund all unpaid-out transactions since the most recent payout.
@spec setup_beneficiary( map(), keyword() ) :: AdyenClient.Client.response()
Set up a beneficiary relationship.
@spec transaction_list( map(), keyword() ) :: AdyenClient.Client.response()
Get a list of transactions for an account holder.
@spec transfer_funds( map(), keyword() ) :: AdyenClient.Client.response()
Transfer funds between platform accounts.