Adyen Cloud Device API (v1).
REST wrapper to send Terminal API messages to cloud-connected terminals without needing direct network access to the terminal.
Summary
Functions
Send a Terminal API request and receive an asynchronous response.
Get the connection status of a device.
Get a list of connected devices for a merchant account.
Send a Terminal API request and receive a synchronous response.
Functions
@spec async(String.t(), String.t(), map(), keyword()) :: AdyenClient.Client.response()
Send a Terminal API request and receive an asynchronous response.
@spec get_status(String.t(), String.t(), keyword()) :: AdyenClient.Client.response()
Get the connection status of a device.
@spec list_connected( String.t(), keyword() ) :: AdyenClient.Client.response()
Get a list of connected devices for a merchant account.
@spec sync(String.t(), String.t(), map(), keyword()) :: AdyenClient.Client.response()
Send a Terminal API request and receive a synchronous response.