Terminal Management / postfmapi (v1) — deprecated.
Assign terminals and look up terminal/store/account associations.
For new integrations use AdyenClient.Management.Terminals.
Summary
Functions
Assign terminals to a merchant account or store.
Get the stores of a merchant account.
Get details of a terminal.
Get the merchant account or store a terminal is assigned to.
Get the list of terminals under a merchant account or store.
Functions
@spec assign( map(), keyword() ) :: AdyenClient.Client.response()
Assign terminals to a merchant account or store.
@spec get_stores( map(), keyword() ) :: AdyenClient.Client.response()
Get the stores of a merchant account.
@spec get_terminal( map(), keyword() ) :: AdyenClient.Client.response()
Get details of a terminal.
@spec get_terminal_under( map(), keyword() ) :: AdyenClient.Client.response()
Get the merchant account or store a terminal is assigned to.
@spec list_terminals( map(), keyword() ) :: AdyenClient.Client.response()
Get the list of terminals under a merchant account or store.